@@ -1,4 +1,5 @@
 import sys
+import traceback
 import os
 import json
 import time
@@ -98,55 +99,50 @@ class Flox(Launcher):
         cls.appdir = APP_DIR
         cls._start = time.time()
         cls._results = []
-        cls.except_results = False
         cls._settings = None
         cls.font_family = '/Resources/#Segoe Fluent Icons'
+        cls.issue_item_title = 'Report Issue'
+        cls.issue_item_subtitle = 'Report this issue to the developer'
 
     @cached_property
     def browser(self):
         return Browser(self.app_settings)
 
+    def exception(self, exception):
+        self.exception_item(exception)
+        self.issue_item(exception)
+
     def _query(self, query):
-        try:
-            self.args = query.lower()
+        self.args = query.lower()
 
-            self.query(query)
-
-        except Exception as e:
-            if self.except_results:
-                self._add_except(e)
-            else:
-                raise
+        self.query(query)
 
     def _context_menu(self, data):
-        try:
+        self.context_menu(data)
 
-            self.context_menu(data)
-
-        except Exception as e:
-            if self.except_results:
-                self._add_except(e)
-            else:
-                raise
-        return self._results
-
-    def _add_except(self, e):
+    def exception_item(self, exception):
         self.add_item(
-            title=e.__class__.__name__,
-            subtitle=str(e),
+            title=exception.__class__.__name__,
+            subtitle=str(exception),
             icon=ICON_APP_ERROR,
-            method='github_issue',
-            parameters=[e.__class__.__name__]
+            method=self.change_query,
+            dont_hide=True
         )
 
-    def github_issue(self, title, log=None):
+    def issue_item(self, e):
+        trace = ''.join(traceback.format_exception(etype=type(e), value=e, tb=e.__traceback__)).replace('\n', '%0A')
+        self.add_item(
+            title=self.issue_item_title,
+            subtitle=self.issue_item_subtitle,
+            icon=ICON_BROWSER,
+            method=self.create_github_issue,
+            parameters=[e.__class__.__name__, trace],
+        )
+
+    def create_github_issue(self, title, trace, log=None):
         url = self.manifest['Website']
         if 'github' in url.lower():
-            if log is None:
-                with open(self.applog, 'r') as l:
-                    log = l.readlines()[-50:]
-            error_msg = urllib.parse.quote_plus(''.join(log))
-            issue_body = f"Please+type+any+relevant+information+here%0A%0A%0A%0A%0A%0A%3Cdetails%3E%3Csummary%3EError+Log%3C%2Fsummary%3E%0A%3Cp%3E%0A%0A%60%60%60%0A{error_msg}%0A%60%60%60%0A%3C%2Fp%3E%0A%3C%2Fdetails%3E"
+            issue_body = f"Please+type+any+relevant+information+here%0A%0A%0A%0A%0A%0A%3Cdetails open%3E%3Csummary%3ETrace+Log%3C%2Fsummary%3E%0A%3Cp%3E%0A%0A%60%60%60%0A{trace}%0A%60%60%60%0A%3C%2Fp%3E%0A%3C%2Fdetails%3E"
             url = f"{url}/issues/new?title={title}&body={issue_body}"
         webbrowser.open(url)
 
